<a name="aea.protocols.generator.validate"></a>
# aea.protocols.generator.validate

This module validates a protocol specification.

<a name="aea.protocols.generator.validate.validate"></a>
#### validate

```python
validate(protocol_specification: ProtocolSpecification) -> Tuple[bool, str]
```

Evaluate whether a protocol specification is valid.

**Arguments**:

- `protocol_specification`: a protocol specification.

**Returns**:

Boolean result, and associated message.

